@@ -5,6 +5,8 @@ import base64
 import random
 import pytest
 import string
+import time
+
 from typing import List, Dict
 
 from workflows_core.api.client import Client
@@ -129,6 +131,7 @@ def test_sentiment_workflow_token(test_client: Client) -> str:
     dataset_id = f"_sample_dataset_{salt}"
     dataset = test_client.Dataset(dataset_id)
     dataset.insert_documents(mock_documents(20))
+    time.sleep(1)
     job_id = str(uuid.uuid4())
     config = dict(
         job_id=job_id,
@@ -148,6 +151,32 @@ def test_sentiment_workflow_token(test_client: Client) -> str:
     test_client.delete_dataset(dataset_id)
 
 
+@pytest.fixture(scope="function")
+def test_simple_workflow_token(test_client: Client) -> str:
+    salt = "".join(random.choices(string.ascii_lowercase, k=10))
+    dataset_id = f"_sample_dataset_{salt}"
+    dataset = test_client.Dataset(dataset_id)
+    dataset.insert_documents(mock_documents(20))
+    time.sleep(1)
+    job_id = str(uuid.uuid4())
+    config = dict(
+        job_id=job_id,
+        authorizationToken=test_client._token,
+        dataset_id=dataset_id,
+        send_email=True,
+    )
+    config_string = json.dumps(config)
+    config_bytes = config_string.encode()
+    workflow_token = base64.b64encode(config_bytes).decode()
+    # test_client._api._trigger(
+    #     dataset_id,
+    #     params=config,
+    #     workflow_id=job_id,
+    # )
+    yield workflow_token
+    test_client.delete_dataset(dataset_id)
+
+
 @pytest.fixture(scope="function")
 def test_cluster_workflow_token(test_client: Client) -> str:
     salt = "".join(random.choices(string.ascii_lowercase, k=10))
@@ -173,21 +202,19 @@ def test_cluster_workflow_token(test_client: Client) -> str:
     yield workflow_token
     test_client.delete_dataset(dataset_id)
 
+
 @pytest.fixture
 def test_keyphrases() -> List[Dict]:
     return [
-            {
-                "_id": "doc_1",
-                "keyphrase": "word",
-                "score": 10,
-                "parent_document": "test_parent",
-            },
-            {
-                "_id": "doc_2",
-                "keyphrase": "word",
-                "score": 10
-            }
-        ]
+        {
+            "_id": "doc_1",
+            "keyphrase": "word",
+            "score": 10,
+            "parent_document": "test_parent",
+        },
+        {"_id": "doc_2", "keyphrase": "word", "score": 10},
+    ]
+
 
 @pytest.fixture
 def test_keyphrase_dataset(test_client: Client, test_dataset_id: str) -> Dataset:
