@@ -409,12 +409,47 @@ class API:
             url=self._base_url + f"/workflows/trigger", headers=self._headers, json=data
         ).json()
 
+    @retry()
+    def _trigger_polling_workflow(
+        self,
+        dataset_id: str,
+        input_field: str,
+        output_field: str,
+        job_id: str,
+        workflow_name: str,
+        # set 95% coverage in case of edge cases like workflow only working
+        # on certain proportion of dataset
+        minimum_coverage: float = 0.95,
+        max_time: float = 6000,
+        sleep_timer: float = 10,
+        workflow_id="poll",
+        version="production_version",
+    ):
+        """
+        Trigger the polling workflow
+        """
+        return self._trigger(
+            dataset_id=dataset_id,
+            params=dict(
+                dataset_id=dataset_id,
+                input_field=input_field,
+                output_field=output_field,
+                minimum_coverage=minimum_coverage,
+                max_time=max_time,
+                sleep_timer=sleep_timer,
+                parent_job_id=job_id,
+                parent_job_name=workflow_name,
+            ),
+            workflow_id=workflow_id,
+            version=version,
+        )
+
     @retry()
     def _update_workflow_progress(
         self,
         workflow_id: str,
         worker_number: int = 0,
-        step: int = 0,
+        step: str = "Workflow",
         n_processed: int = 0,
         n_total: int = 0,
     ):
@@ -563,6 +598,7 @@ class API:
         alias: str,
         page: int = 0,
         page_size: int = 100,
+        sort: list = [],
     ):
         """
         List keyphrases
@@ -571,11 +607,11 @@ class API:
             url=self._base_url
             + f"/datasets/{dataset_id}/fields/{field}.{alias}/keyphrase/list",
             headers=self._headers,
-            json={"page": page, "page_size": page_size},
+            json={"page": page, "page_size": page_size, "sort": sort},
         )
         return get_response(response)
 
-    @retry
+    @retry()
     def _facets(
         self,
         dataset_id: str,
@@ -595,3 +631,87 @@ class API:
             ),
         )
         return get_response(response)
+
+    @retry()
+    def _upsert_dataset_settings(
+        self,
+        dataset_id: str,
+        settings: Optional[Dict[str, Any]] = None,
+    ):
+        response = requests.post(
+            url=self._base_url + f"/datasets/{dataset_id}/settings",
+            headers=self._headers,
+            json=dict(settings={} if settings is None else settings),
+        )
+        return get_response(response)
+
+    @retry()
+    def _get_dataset_settings(
+        self,
+        dataset_id: str,
+    ):
+        response = requests.get(
+            url=self._base_url + f"/datasets/{dataset_id}/settings",
+            headers=self._headers,
+        )
+        return get_response(response)
+
+    @retry()
+    def _create_deployable(
+        self, dataset_id: Optional[str] = None, config: Optional[Dict[str, Any]] = None
+    ):
+        response = requests.post(
+            url=self._base_url + "/deployables/create",
+            headers=self._headers,
+            json=dict(
+                dataset_id=dataset_id,
+                configuration={} if config is None else config,
+            ),
+        )
+        return get_response(response)
+
+    @retry()
+    def _share_dashboard(self, deployable_id: str):
+        response = requests.post(
+            url=self._base_url + f"/deployablegroups/{deployable_id}/share",
+            headers=self._headers,
+        )
+        return get_response(response)
+
+    @retry()
+    def _unshare_dashboard(self, deployable_id: str):
+        response = requests.post(
+            url=self._base_url + f"/deployablegroups/{deployable_id}/private",
+            headers=self._headers,
+        )
+        return get_response(response)
+
+    @retry()
+    def _get_deployable(self, deployable_id: str):
+        response = requests.get(
+            url=self._base_url + f"/deployables/{deployable_id}/get",
+            headers=self._headers,
+        )
+        return get_response(response)
+
+    @retry()
+    def _delete_deployable(self, deployable_id: str):
+        response = requests.post(
+            url=self._base_url + f"/deployables/delete",
+            headers=self._headers,
+            json=dict(
+                id=deployable_id,
+            ),
+        )
+        return get_response(response)
+
+    @retry()
+    def _list_deployables(self, page_size: int):
+        response = requests.get(
+            url=self._base_url + "/deployables/list",
+            headers=self._headers,
+            params=dict(
+                page_size=page_size,
+            ),
+        )
+        return get_response(response)
